@@ -6,6 +6,8 @@ import logging
 import os
 import subprocess
 
+import dvc.repo
+
 import calkit
 from calkit.config import get_app_name
 
@@ -13,19 +15,23 @@ logger = logging.getLogger(__package__)
 logger.setLevel(logging.INFO)
 
 
-def configure_remote():
-    project_name = calkit.git.detect_project_name()
+def configure_remote(wdir: str = None):
+    project_name = calkit.git.detect_project_name(path=wdir)
     base_url = calkit.cloud.get_base_url()
     remote_url = f"{base_url}/projects/{project_name}/dvc"
     subprocess.check_call(
-        ["dvc", "remote", "add", "-d", "-f", get_app_name(), remote_url]
+        ["dvc", "remote", "add", "-d", "-f", get_app_name(), remote_url],
+        cwd=wdir,
     )
     subprocess.check_call(
-        ["dvc", "remote", "modify", get_app_name(), "auth", "custom"]
+        ["dvc", "remote", "modify", get_app_name(), "auth", "custom"],
+        cwd=wdir,
     )
 
 
-def set_remote_auth(remote_name: str = None, always_auth: bool = False):
+def set_remote_auth(
+    remote_name: str = None, always_auth: bool = False, wdir: str = None
+):
     """Get a token and set it in the local DVC config so we can interact with
     the cloud as an HTTP remote.
     """
@@ -48,7 +54,8 @@ def set_remote_auth(remote_name: str = None, always_auth: bool = False):
             remote_name,
             "custom_auth_header",
             "Authorization",
-        ]
+        ],
+        cwd=wdir,
     )
     subprocess.check_call(
         [
@@ -59,7 +66,8 @@ def set_remote_auth(remote_name: str = None, always_auth: bool = False):
             remote_name,
             "password",
             f"Bearer {settings.dvc_token}",
-        ]
+        ],
+        cwd=wdir,
     )
 
 
@@ -96,3 +104,9 @@ def get_remotes(wdir: str = None) -> dict[str, str]:
         name, url = line.split("\t")
         resp[name] = url
     return resp
+
+
+def list_paths(wdir: str = None) -> list[str]:
+    """List paths tracked with DVC."""
+    dvc_repo = dvc.repo.Repo(wdir)
+    return [p.get("path") for p in dvc_repo.ls(".", dvc_only=True)]
